@@ -87,7 +87,6 @@ NEOInitVideo(ScreenPtr pScreen)
     numAdaptors = xf86XVListGenericAdaptors(pScrn, &overlayAdaptors);
 
     if (nPtr->NeoChipset > NM2070 
-	&& !nPtr->noLinear 
 	&& nPtr->NeoMMIOBase2 != NULL){
 	nPtr->video = TRUE;
 	newAdaptor = NEOSetupVideo(pScreen);
@@ -100,7 +99,7 @@ NEOInitVideo(ScreenPtr pScreen)
 	    numAdaptors = 1;
 	    overlayAdaptors = &newAdaptor;
 	} else {
-	    newAdaptors = xalloc((numAdaptors + 1) 
+	    newAdaptors = malloc((numAdaptors + 1) 
 				 * sizeof(XF86VideoAdaptorPtr*));
 	    if (newAdaptors){
 		memcpy(newAdaptors, overlayAdaptors, 
@@ -115,7 +114,7 @@ NEOInitVideo(ScreenPtr pScreen)
 	xf86XVScreenInit(pScreen, overlayAdaptors, numAdaptors);
 
     if (newAdaptors)
-	xfree(newAdaptors);
+	free(newAdaptors);
 }
 
 static XF86VideoEncodingRec NEOVideoEncodings[] =
@@ -212,7 +211,7 @@ NEOSetupVideo(ScreenPtr pScreen)
 #ifdef DEBUG
     xf86DrvMsg(pScrn->scrnIndex,X_INFO,"NEOSetupVideo\n");
 #endif
-    if ((overlayAdaptor = xcalloc(1, sizeof(XF86VideoAdaptorRec) +
+    if ((overlayAdaptor = calloc(1, sizeof(XF86VideoAdaptorRec) +
 			      sizeof(DevUnion) + 
 			      sizeof(NEOPortRec))) == NULL){
 	return (NULL);
@@ -919,7 +918,7 @@ NEOInitOffscreenImages(ScreenPtr pScreen)
 #ifdef DEBUG
     xf86DrvMsg(xf86Screens[pScreen->myNum]->scrnIndex,X_INFO,"NEOInitOffscreenImages\n");
 #endif
-    if ((offscreenImages = xalloc(sizeof(XF86OffscreenImageRec))) == NULL){
+    if ((offscreenImages = malloc(sizeof(XF86OffscreenImageRec))) == NULL){
 	return;
     }
 
@@ -1018,19 +1017,19 @@ NEOAllocSurface(ScrnInfoPtr pScrn, int id,
 
     surface->width = width;
     surface->height = height;
-    if ((surface->pitches = xalloc(sizeof(int))) == NULL){
+    if ((surface->pitches = malloc(sizeof(int))) == NULL){
 	xf86FreeOffscreenLinear(linear);
 	return (BadAlloc);
     }
-    if ((surface->offsets = xalloc(sizeof(int))) == NULL){
-	xfree(surface->pitches);
+    if ((surface->offsets = malloc(sizeof(int))) == NULL){
+	free(surface->pitches);
 	xf86FreeOffscreenLinear(linear);
 	return (BadAlloc);
     }
 
-    if ((pPriv = xalloc(sizeof(NEOOffscreenRec))) == NULL){
-	xfree(surface->pitches);
-	xfree(surface->offsets);
+    if ((pPriv = malloc(sizeof(NEOOffscreenRec))) == NULL){
+	free(surface->pitches);
+	free(surface->offsets);
 	xf86FreeOffscreenLinear(linear);
 	return (BadAlloc);
     }
@@ -1058,9 +1057,9 @@ NEOFreeSurface(XF86SurfacePtr surface)
 	NEOStopSurface(surface);
 
     xf86FreeOffscreenLinear(pPriv->linear);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
     return (Success);
 }
 
